==> nextcloud-13.0.1.tgz: nextcloud/apps/gallery/l10n/sl.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerija",
    "There was a problem reading files from this album" : "Prišlo je do težav med branjem datotek tega albuma",
    "Aborting preview. Could not find the file" : "Predogled je prekinjen. Ni mogoče najti datoteke.",
    "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
    "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
    "No compatible server found at {remote}" : "Ne najdem kompatibilnega strežnika na {remote}",
    "Invalid server url" : "Neveljaven URL naslov",
    "Could not load the description" : "Ni mogoče naložiti opisa",
    "Could not load the description: " : "Ni mogoče naložiti opisa:",
    "Copyright" : "Avtorske pravice",
    "Could not load the copyright notice: " : "Ni mogoče naložiti obvestila avtorskih pravic:",
    "Copyright notice" : "Obvestilo avtorskih pravic",
    "Link to copyright document" : "Povezava na dokument o avtorski zaščiti",
    "This application may not work properly on your browser." : "Ta program morda ne bo deloval pravilno v trenutnem brskalniku",
    "For an improved experience, please install one of the following alternatives" : "Za najboljšo izkušnjo namestite enega izmed navedenih programov",
    "Your browser is not supported!" : "Trenutno uporabljen brskalnik ni podprt!",
    "please install one of the following alternatives" : "priporočljivo je namestiti enega od navedenih možnih paketov",
    "Album cannot be shown" : "Albuma ni mogoče pokazati",
    "No media files found" : "Ni najdenih predstavnih datotek",
    "Upload new files via drag and drop or by using the [+] button above" : "Datoteke je mogoče poslati v oblak z gumbom [+] ali z miško s povleci in spusti v okno mape.",
    "Configuration error" : "Napaka nastavitve",
    "New" : "Novo",
    "Hide Album" : "Skrij album",
    "Could not hide album" : "Albuma ni mogoče skriti",
    "Error loading slideshow template" : "Napaka nalaganja predloge za slikovno predstavitev",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Napaka!</strong> Ni mogoče ustvariti predogleda te datoteke.<br>Nadaljujte na naslednjo sliko, trenutna z napako pa bo odstranjena.",
    "Next" : "Naslednja",
    "Play" : "Predvajaj",
    "Pause" : "Premor",
    "Previous" : "Predhodna",
    "Close" : "Zapri",
    "Download" : "Prejmi",
    "Toggle background" : "Preklopi ozadje",
    "Delete" : "Izbriši",
    "Share" : "Souporaba",
    "Could not create file \"{file}\" because it already exists" : "Ni mogoče ustvariti datoteke \"{file}\", ker že obstaja",
    "Could not create file \"{file}\"" : "Ni mogoče ustvariti datoteke \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "Upload" : "Pošiljanje",
    "Error" : "Napaka",
    "Error while sharing" : "Napaka med souporabo",
    "Error while unsharing" : "Napaka med odstranjevanjem souporabe",
    "Error while changing permissions" : "Napaka med spreminjanjem dovoljenj",
    "Shared with you and the group {group} by {owner}" : "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
    "Shared with you by {owner}" : "V souporabi z vami. Lastnik je {owner}.",
    "Share with users or groups …" : "Souporaba z uporabniki ali skupinami ...",
    "Share with users, groups or remote users …" : "Uporabniki, skupine ali zunanji uporabniki ...",
    "Share link" : "Povezava za souporabo",
    "The public link will expire no later than {days} days after it is created" : "Javna povezava bo potekla {days} dni po ustvarjanju.",
    "Link" : "Povezava",
    "Password protect" : "Zaščiti z geslom",
    "Password" : "Geslo",
    "Choose a password for the public link" : "Izberite geslo za javno povezavo",
    "Allow editing" : "Dovoli urejanje",
    "Email link to person" : "Posreduj povezavo po elektronski pošti",
    "Send" : "Pošlji",
    "Set expiration date" : "Nastavi datum preteka",
    "Expiration" : "Datum preteka",
    "Expiration date" : "Datum preteka",
    "An error occured. Please try again" : "Prišlo je do napake. Poskusite znova.",
    "Adding user..." : "Dodajanje uporabnika ...",
    "group" : "skupina",
    "remote" : "oddaljeno",
    "Resharing is not allowed" : "Nadaljnje omogočanje souporabe ni dovoljeno",
    "Error while retrieving shares" : "Napaka pri pridobivanju souporabljenih mest",
    "Unshare" : "Prekini souporabo",
    "notify by email" : "obvesti po elektronski pošti",
    "can share" : "lahko omogoči souporabo",
    "can edit" : "lahko ureja",
    "access control" : "nadzor dostopa",
    "create" : "ustvari",
    "change" : "spremeni",
    "delete" : "izbriši",
    "Password protected" : "Zaščiteno z geslom",
    "Error unsetting expiration date" : "Napaka brisanja datuma preteka",
    "Error setting expiration date" : "Napaka nastavljanja datuma preteka",
    "Email sent" : "Elektronska pošta je poslana",
    "Warning" : "Opozorilo",
    "This share is password-protected" : "To mesto je zaščiteno z geslom.",
    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
    "Sort by name" : "Razvrsti po imenu",
    "Sort by date" : "Razvrsti po datumu",
    "Cancel upload" : "Prekliči pošiljanje",
    "Album information" : "Podrobnosti albuma",
    "File list" : "Seznam datotek",
    "Sorry, this file could not be found." : "Datoteke ni mogoče najti.",
    "Reasons might be:" : "Vzrok je lahko:",
    "the wrong file ID was provided" : "naveden je napačen ID datoteke",
    "the file was removed" : "datoteka je bila odstranjena",
    "the file is corrupt" : "datoteka je okvarjena",
    "the encryption key is missing" : "manjka ključ za kodiranje",
    "Here is the error message returned by the server: " : "Sporočilo s strežnika o napaki: ",
    "Sorry, but the server could not fulfill your request." : "Zahteve ni mogoče izpolniti.",
    "Possible reasons for the problem:" : "Možno vzroki za težavo:",
    "a conflicting app was installed" : "nameščen je neskladen program",
    "a required component is missing or was disconnected" : "zahtevana povezava ni na voljo ali pa je povezava prekinjena",
    "the filesystem is not readable" : "datotečnega sistema ni mogoče brati",
    "Sorry, this link doesn't seem to work anymore." : "Videti je, da povezava ne deluje več.",
    "the item was removed" : "predmet je odstranjen",
    "the link has expired" : "povezava je potekla",
    "sharing is disabled" : "souporaba je onemogočena.",
    "For more information, please ask the person who has sent you this link." : "Za več podrobnosti stopite v stik z osebo, ki je poslala to povezavo.",
    "Add to your Nextcloud" : "Dodaj v svoj Nextcloud",
    "Picture view" : "Slikovni pogled",
    "Gallery view" : "Galerijski pogled",
    "Sending ..." : "Pošiljanje ..."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/gallery/l10n/sl.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "Galerija",
    "There was a problem reading files from this album" : "Prišlo je do težav med branjem datotek tega albuma",
    "Aborting preview. Could not find the file" : "Predogled je prekinjen. Ni mogoče najti datoteke.",
    "Could not move \"{file}\", target exists" : "Datoteke \"{file}\" ni mogoče premakniti, ker cilj že obstaja",
    "Could not move \"{file}\"" : "Ni mogoče premakniti \"{file}\"",
    "No compatible server found at {remote}" : "Skladnega strežnika na {remote} ni mogoče najti",
    "Invalid server url" : "Neveljaven URL naslov",
    "Could not load the description" : "Ni mogoče naložiti opisa",
    "Could not load the description: " : "Ni mogoče naložiti opisa:",
    "Copyright" : "Avtorske pravice",
    "Could not load the copyright notice: " : "Ni mogoče naložiti obvestila avtorskih pravic:",
    "Copyright notice" : "Obvestilo avtorskih pravic",
    "Link to copyright document" : "Povezava na dokument o avtorski zaščiti",
    "This application may not work properly on your browser." : "Ta program morda ne bo deloval pravilno v trenutnem brskalniku",
    "For an improved experience, please install one of the following alternatives" : "Za najboljšo izkušnjo namestite enega izmed navedenih programov",
    "Your browser is not supported!" : "Trenutno uporabljen brskalnik ni podprt!",
    "please install one of the following alternatives" : "priporočljivo je namestiti enega od navedenih možnih paketov",
    "Album cannot be shown" : "Albuma ni mogoče pokazati",
    "No media files found" : "Ni najdenih predstavnih datotek",
    "Upload new files via drag and drop or by using the [+] button above" : "Datoteke je mogoče poslati v oblak z uporabo gumba [+], ali z miško s povleci in spusti v okno mape.",
    "Configuration error" : "Napaka nastavitve",
    "Hide Album" : "Skrij album",
    "Could not hide album" : "Albuma ni mogoče skriti",
    "Error loading slideshow template" : "Napaka nalaganja predloge za slikovno predstavitev",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>Napaka!</strong> Ni mogoče ustvariti predogleda te datoteke.<br>Nadaljujte na naslednjo sliko, trenutna z napako pa bo odstranjena.",
    "Next" : "Naslednja",
    "Play" : "Predvajaj",
    "Pause" : "Premor",
    "Previous" : "Predhodna",
    "Close" : "Zapri",
    "Download" : "Prejmi",
    "Toggle background" : "Preklopi ozadje",
    "Delete" : "Izbriši",
    "Share" : "Souporaba",
    "Could not create file \"{file}\" because it already exists" : "Ni mogoče ustvariti datoteke \"{file}\", ker že obstaja",
    "Could not create file \"{file}\"" : "Ni mogoče ustvariti datoteke \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neveljavno ime datoteke.",
    "File name cannot be empty." : "Ime datoteke ne sme biti prazno polje.",
    "Upload" : "Pošiljanje",
    "Error" : "Napaka",
    "Error while sharing" : "Napaka med souporabo",
    "Error while unsharing" : "Napaka med odstranjevanjem souporabe",
    "Error while changing permissions" : "Napaka med spreminjanjem dovoljenj",
    "Shared with you and the group {group} by {owner}" : "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
    "Shared with you by {owner}" : "V souporabi z vami. Lastnik je {owner}.",
    "Share with users or groups …" : "Souporaba z uporabniki ali skupinami ...",
    "Share with users, groups or remote users …" : "Uporabniki, skupine ali zunanji uporabniki ...",
    "Share link" : "Povezava za souporabo",
    "The public link will expire no later than {days} days after it is created" : "Javna povezava bo potekla {days} dni po ustvarjanju.",
    "Link" : "Povezava",
    "Password protect" : "Zaščiti z geslom",
    "Password" : "Geslo",
    "Choose a password for the public link" : "Izberite geslo za javno povezavo",
    "Allow editing" : "Dovoli urejanje",
    "Email link to person" : "Posreduj povezavo po elektronski pošti",
    "Send" : "Pošlji",
    "Set expiration date" : "Nastavi datum preteka",
    "Expiration" : "Datum preteka",
    "Expiration date" : "Datum preteka",
    "Adding user..." : "Dodajanje uporabnika ...",
    "group" : "skupina",
    "remote" : "oddaljeno",
    "Resharing is not allowed" : "Nadaljnje omogočanje souporabe ni dovoljeno",
    "Error while retrieving shares" : "Napaka pri pridobivanju souporabljenih mest",
    "Unshare" : "Prekini souporabo",
    "notify by email" : "obvesti po elektronski pošti",
    "can share" : "lahko omogoči souporabo",
    "can edit" : "lahko ureja",
    "access control" : "nadzor dostopa",
    "create" : "ustvari",
    "change" : "spremeni",
    "delete" : "izbriši",
    "Password protected" : "Zaščiteno z geslom",
    "Error unsetting expiration date" : "Napaka brisanja datuma preteka",
    "Error setting expiration date" : "Napaka nastavljanja datuma preteka",
    "Email sent" : "Elektronska pošta je poslana",
    "Warning" : "Opozorilo",
    "Add to your Nextcloud" : "Dodaj v oblak Nextcloud",
    "This share is password-protected" : "To mesto je zaščiteno z geslom.",
    "The password is wrong. Try again." : "Geslo je napačno. Poskusite znova.",
    "Sort by name" : "Razvrsti po imenu",
    "Sort by date" : "Razvrsti po datumu",
    "Cancel upload" : "Prekliči pošiljanje",
    "Album information" : "Podrobnosti albuma",
    "File list" : "Seznam datotek",
    "Sorry, this file could not be found." : "Datoteke ni mogoče najti.",
    "Reasons might be:" : "Vzrok je lahko:",
    "the wrong file ID was provided" : "naveden je napačen ID datoteke",
    "the file was removed" : "datoteka je bila odstranjena",
    "the file is corrupt" : "datoteka je okvarjena",
    "the encryption key is missing" : "manjka ključ za kodiranje",
    "Here is the error message returned by the server: " : "Sporočilo s strežnika o napaki: ",
    "Sorry, but the server could not fulfill your request." : "Zahteve ni mogoče izpolniti.",
    "Possible reasons for the problem:" : "Možno vzroki za težavo:",
    "a conflicting app was installed" : "nameščen je neskladen program",
    "a required component is missing or was disconnected" : "zahtevana povezava ni na voljo ali pa je povezava prekinjena",
    "the filesystem is not readable" : "datotečnega sistema ni mogoče brati",
    "Sorry, this link doesn't seem to work anymore." : "Videti je, da povezava ne deluje več.",
    "the item was removed" : "predmet je odstranjen",
    "the link has expired" : "povezava je potekla",
    "sharing is disabled" : "souporaba je onemogočena.",
    "For more information, please ask the person who has sent you this link." : "Za več podrobnosti stopite v stik z osebo, ki je to povezavo poslala .",
    "Picture view" : "Slikovni pogled",
    "New" : "Novo",
    "An error occured. Please try again" : "Prišlo je do napake. Poskusite znova.",
    "Sending ..." : "Poteka pošiljanje ..."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
